==> tecfy_core_package-0.1.102.tar.gz: lib/views/home/dasboard.page.dart <==
part of tecfy_core_client_package;

class DashboardPage extends StatefulWidget {
  @override
  _DashboardPageState createState() => _DashboardPageState();
}

class _DashboardPageState
    extends AppStateView<DashboardPage, DashboardController> {
  @override
  void initState() {
    super.initState();
    _controller = DashboardController(this);
  }

  onItemTab(type) async {
    if (type.onClick == null || type.onClick.isEmpty) return;
    if (type.onClick.startsWith('EntityList:')) {
      AppNavigator.navigateTo(context,
          () => EntityListPage(type.onClick.replaceAll('EntityList:', '')));
      return;
    }
    if (type.onClick.startsWith('Report:')) {
      var result =
          await TecfyBasicApp.apiService.httpGetDynamic('Report/GetList');
      var reportName = type.onClick.replaceAll('Report:', '');
      AppNavigator.navigateTo(
          context,
          () => ReportDetailPage(
              result.data.firstWhere((s) => s['dbName'] == reportName), []));
      return;
    }
  }

  @override
  Widget build(BuildContext context) {
    return BasePage(context, 'Main Page',
        isHome: true,
        // appBarActions: kIsWeb || Platform.isWindows
        //     ? [
        //         IconButton(
        //             icon: Icon(Icons.refresh),
        //             onPressed: _controller.refreshData)
        //       ]
        //     : null,
        child: _controller.dashboards == null
            ? Center(
                child: CircularProgressIndicator(
                    valueColor:
                        AlwaysStoppedAnimation<Color>(ThemeService.mainColor)))
            : _controller.dashboards.length == 0
                ? Container()
                : _controller.dashboards.length == 1
                    ? getWidgetData()
                    : Column(
                        children: [
                          getFilterWidget(),
                          Expanded(child: getWidgetData())
                        ],
                      ));
  }

  Widget getFilterWidget() {
    return Container(
      constraints: BoxConstraints(maxWidth: ThemeService.containerWidth),
      padding: EdgeInsets.only(top: 10),
      child: Align(
          alignment: Alignment.centerLeft,
          child: SingleChildScrollView(
            scrollDirection: Axis.horizontal,
            child: Row(
              crossAxisAlignment: CrossAxisAlignment.end,
              children: [
                SizedBox(width: 10),
                // Container(
                //     constraints: BoxConstraints(maxWidth: 200),
                //     child: DropdownButtonHideUnderline(
                //       child: DropdownButtonFormField(
                //         //decoration: InputDecoration(labelText: 'Dashboard'),
                //         value: _controller.activeDashboard?.id,
                //         onChanged: (v) {
                //           _controller.activeDashboard =
                //               _controller.dashboards.firstWhere((e) => e.id == v);
                //           setState(() {});
                //         },
                //         items: _controller.dashboards
                //             .map<DropdownMenuItem>((d) => DropdownMenuItem(
                //                   child: Text(d.name),
                //                   value: d.id,
                //                 ))
                //             .toList(),
                //       ),
                //     )),

                MaterialButton(
                    child: Text(trans('Today')),
                    color: _controller.filterDate == 'Today'
                        ? ThemeService.secondryColor
                        : ThemeService.mainColor,
                    shape: RoundedRectangleBorder(
                        borderRadius: BorderRadius.circular(0)),
                    elevation: 0,
                    onPressed: () => _controller.filterDateChanged('Today')),
                VerticalDivider(
                    color: Colors.white,
                    thickness: 0.1,
                    width: 0.1,
                    endIndent: 0,
                    indent: 0),
                MaterialButton(
                    child: Text(trans('Week')),
                    elevation: 0,
                    shape: RoundedRectangleBorder(
                        borderRadius: BorderRadius.circular(0)),
                    color: _controller.filterDate == 'Week'
                        ? ThemeService.secondryColor
                        : ThemeService.mainColor,
                    onPressed: () => _controller.filterDateChanged('Week')),
                VerticalDivider(
                    color: Colors.white,
                    thickness: 0.1,
                    width: 0.1,
                    endIndent: 0,
                    indent: 0),
                MaterialButton(
                    child: Text(trans('Month')),
                    elevation: 0,
                    shape: RoundedRectangleBorder(
                        borderRadius: BorderRadius.circular(0)),
                    color: _controller.filterDate == 'Month'
                        ? ThemeService.secondryColor
                        : ThemeService.mainColor,
                    onPressed: () => _controller.filterDateChanged('Month')),
                VerticalDivider(
                    color: Colors.white,
                    thickness: 0.1,
                    width: 0.1,
                    endIndent: 0,
                    indent: 0),
                MaterialButton(
                    child: Text(trans('Year')),
                    color: _controller.filterDate == 'Year'
                        ? ThemeService.secondryColor
                        : ThemeService.mainColor,
                    shape: RoundedRectangleBorder(
                        borderRadius: BorderRadius.circular(0)),
                    elevation: 0,
                    onPressed: () => _controller.filterDateChanged('Year')),

                SizedBox(width: 10),
              ],
            ),
          )),
    );
  }

  Widget getWidgetData() {
    return Container(
      constraints: BoxConstraints(maxWidth: ThemeService.containerWidth),
      padding: EdgeInsets.only(top: 20),
      child: AnimationLimiter(
        child: SmartRefresher(
          enablePullDown: true,
          enablePullUp: false,
          controller: _controller.refreshController,
          header: WaterDropHeader(complete: Icon(Icons.done)),
          onRefresh: _controller.refreshData,
          child: ListView(
            children: [
              // Row(children: [
              //   Container(
              //       child: Row(
              //     children: [
              //       TextButton(child: Text('Today'), onPressed: () {}),
              //       VerticalDivider(color: Colors.black26, thickness: 1),
              //       TextButton(child: Text('Week'), onPressed: () {}),
              //       VerticalDivider(),
              //       TextButton(child: Text('Month'), onPressed: () {}),
              //       VerticalDivider(),
              //       TextButton(child: Text('Year'), onPressed: () {}),
              //     ],
              //   ))
              // ]),
              getWrap(_controller.activeDashboard.items
                  .where((e) => e.type == "Statistic")
                  .toList()),
              getWrap(_controller.activeDashboard.items
                  .where((e) => e.type == "Chart")
                  .toList()),
            ],
          ),
        ),
      ),
    );
  }

  getWrap(List<DashboardItemBase> items) {
    return Wrap(
      alignment: WrapAlignment.center,
      runAlignment: WrapAlignment.center,
      crossAxisAlignment: WrapCrossAlignment.start,
      children: List.generate(
        items.length,
        (index) => AnimationConfiguration.staggeredList(
          position: index,
          duration: const Duration(milliseconds: 375),
          child: SlideAnimation(
            verticalOffset: 100.0,
            horizontalOffset: 100,
            child: FadeInAnimation(
                child: items[index].type == "Statistic"
                    ? DashboardStatisticsComponenet(items[index])
                    : items[index].type == "Chart"
                        ? DashboardChartComponenet(items[index])
                        : Text(_controller
                            .activeDashboard.items[index].displayName)),
          ),
        ),
      ),
    );
  }
}

==> tecfy_core_package-1.0.1.tar.gz: lib/views/home/dasboard.page.dart <==
part of tecfy_core_client_package;

class DashboardPage extends StatefulWidget {
  @override
  _DashboardPageState createState() => _DashboardPageState();
}

class _DashboardPageState
    extends AppStateView<DashboardPage, DashboardController> {
  @override
  void initState() {
    super.initState();
    _controller = DashboardController(this);
  }

  onItemTab(type) async {
    if (type.onClick == null || type.onClick.isEmpty) return;
    if (type.onClick.startsWith('EntityList:')) {
      AppNavigator.navigateTo(context,
          () => EntityListPage(type.onClick.replaceAll('EntityList:', '')));
      return;
    }
    if (type.onClick.startsWith('Report:')) {
      var result =
          await TecfyBasicApp.apiService.httpGetDynamic('Report/GetList');
      var reportName = type.onClick.replaceAll('Report:', '');
      AppNavigator.navigateTo(
          context,
          () => ReportDetailPage(
              result.data.firstWhere((s) => s['dbName'] == reportName), []));
      return;
    }
  }

  @override
  Widget build(BuildContext context) {
    return BasePage(context, 'Main Page',
        isHome: true,
        // appBarActions: kIsWeb || Platform.isWindows
        //     ? [
        //         IconButton(
        //             icon: Icon(Icons.refresh),
        //             onPressed: _controller.refreshData)
        //       ]
        //     : null,
        child: _controller.dashboards == null
            ? Center(
                child: CircularProgressIndicator(
                    valueColor:
                        AlwaysStoppedAnimation<Color>(ThemeService.mainColor)))
            : _controller.dashboards?.length == 0
                ? Container()
                : _controller.dashboards?.length == 1
                    ? getWidgetData()
                    : Column(
                        children: [
                          getFilterWidget(),
                          Expanded(child: getWidgetData())
                        ],
                      ));
  }

  Widget getFilterWidget() {
    return Container(
      constraints: BoxConstraints(maxWidth: ThemeService.containerWidth),
      padding: EdgeInsets.only(top: 10),
      child: Align(
          alignment: Alignment.centerLeft,
          child: SingleChildScrollView(
            scrollDirection: Axis.horizontal,
            child: Row(
              crossAxisAlignment: CrossAxisAlignment.end,
              children: [
                SizedBox(width: 10),
                // Container(
                //     constraints: BoxConstraints(maxWidth: 200),
                //     child: DropdownButtonHideUnderline(
                //       child: DropdownButtonFormField(
                //         //decoration: InputDecoration(labelText: 'Dashboard'),
                //         value: _controller.activeDashboard?.id,
                //         onChanged: (v) {
                //           _controller.activeDashboard =
                //               _controller.dashboards.firstWhere((e) => e.id == v);
                //           setState(() {});
                //         },
                //         items: _controller.dashboards
                //             .map<DropdownMenuItem>((d) => DropdownMenuItem(
                //                   child: Text(d.name),
                //                   value: d.id,
                //                 ))
                //             .toList(),
                //       ),
                //     )),

                MaterialButton(
                    child: Text(trans('Today')),
                    color: _controller.filterDate == 'Today'
                        ? ThemeService.secondryColor
                        : ThemeService.mainColor,
                    shape: RoundedRectangleBorder(
                        borderRadius: BorderRadius.circular(0)),
                    elevation: 0,
                    onPressed: () => _controller.filterDateChanged('Today')),
                VerticalDivider(
                    color: Colors.white,
                    thickness: 0.1,
                    width: 0.1,
                    endIndent: 0,
                    indent: 0),
                MaterialButton(
                    child: Text(trans('Week')),
                    elevation: 0,
                    shape: RoundedRectangleBorder(
                        borderRadius: BorderRadius.circular(0)),
                    color: _controller.filterDate == 'Week'
                        ? ThemeService.secondryColor
                        : ThemeService.mainColor,
                    onPressed: () => _controller.filterDateChanged('Week')),
                VerticalDivider(
                    color: Colors.white,
                    thickness: 0.1,
                    width: 0.1,
                    endIndent: 0,
                    indent: 0),
                MaterialButton(
                    child: Text(trans('Month')),
                    elevation: 0,
                    shape: RoundedRectangleBorder(
                        borderRadius: BorderRadius.circular(0)),
                    color: _controller.filterDate == 'Month'
                        ? ThemeService.secondryColor
                        : ThemeService.mainColor,
                    onPressed: () => _controller.filterDateChanged('Month')),
                VerticalDivider(
                    color: Colors.white,
                    thickness: 0.1,
                    width: 0.1,
                    endIndent: 0,
                    indent: 0),
                MaterialButton(
                    child: Text(trans('Year')),
                    color: _controller.filterDate == 'Year'
                        ? ThemeService.secondryColor
                        : ThemeService.mainColor,
                    shape: RoundedRectangleBorder(
                        borderRadius: BorderRadius.circular(0)),
                    elevation: 0,
                    onPressed: () => _controller.filterDateChanged('Year')),

                SizedBox(width: 10),
              ],
            ),
          )),
    );
  }

  Widget getWidgetData() {
    return Container(
      constraints: BoxConstraints(maxWidth: ThemeService.containerWidth),
      padding: EdgeInsets.only(top: 20),
      child: AnimationLimiter(
        child: SmartRefresher(
          enablePullDown: true,
          enablePullUp: false,
          controller: _controller.refreshController,
          header: WaterDropHeader(complete: Icon(Icons.done)),
          onRefresh: _controller.refreshData,
          child: ListView(
            children: [
              // Row(children: [
              //   Container(
              //       child: Row(
              //     children: [
              //       TextButton(child: Text('Today'), onPressed: () {}),
              //       VerticalDivider(color: Colors.black26, thickness: 1),
              //       TextButton(child: Text('Week'), onPressed: () {}),
              //       VerticalDivider(),
              //       TextButton(child: Text('Month'), onPressed: () {}),
              //       VerticalDivider(),
              //       TextButton(child: Text('Year'), onPressed: () {}),
              //     ],
              //   ))
              // ]),
              getWrap(_controller.activeDashboard?.items
                      .where((e) => e.type == "Statistic")
                      .toList() ??
                  []),
              getWrap(_controller.activeDashboard?.items
                      .where((e) => e.type == "Chart")
                      .toList() ??
                  []),
            ],
          ),
        ),
      ),
    );
  }

  getWrap(List<DashboardItemBase> items) {
    return Wrap(
      alignment: WrapAlignment.center,
      runAlignment: WrapAlignment.center,
      crossAxisAlignment: WrapCrossAlignment.start,
      children: List.generate(
        items.length,
        (index) => AnimationConfiguration.staggeredList(
          position: index,
          duration: const Duration(milliseconds: 375),
          child: SlideAnimation(
            verticalOffset: 100.0,
            horizontalOffset: 100,
            child: FadeInAnimation(
                child: items[index].type == "Statistic"
                    ? DashboardStatisticsComponenet(items[index])
                    : items[index].type == "Chart"
                        ? DashboardChartComponenet(
                            items[index] as DashboardChart)
                        : Text(_controller
                                .activeDashboard?.items[index].displayName ??
                            '')),
          ),
        ),
      ),
    );
  }
}
